@@ -1,3 +1,2 @@
-"existsTemp" <-
-function (x, mode = "any")
+existsTemp <- function (x, mode = "any")
     exists(x, envir = TempEnv(), mode = mode, inherits = FALSE)
