@@ -5,7 +5,8 @@ isHelp <- function (topic, package = NULL, lib.loc = NULL)
     if (!is.character(topic))  topic <- deparse(topic)[1L]
     
 	pkgpaths <- find.package(package, lib.loc, verbose = FALSE)
-    file <- utils:::index.search(topic, pkgpaths, TRUE)
+	utilsNS <- getNamespace("utils")
+	file <- utilsNS$index.search(topic, pkgpaths, TRUE)
     if (!length(file)) return(c(help = FALSE, example = FALSE))
     
 	packagePath <- dirname(dirname(file))
@@ -15,7 +16,7 @@ isHelp <- function (topic, package = NULL, lib.loc = NULL)
     tf <- tempfile("Rex")
 	on.exit(unlink(tf))
     encoding <- "UTF-8"
-    tools::Rd2ex(utils:::.getHelpFile(file), tf)
+	tools::Rd2ex(utilsNS$.getHelpFile(file), tf)
     if (!file.exists(tf)) {
         c(help = TRUE, example = FALSE)
     } else c(help = TRUE, example = TRUE)
